summaryrefslogtreecommitdiff
path: root/Tools
diff options
context:
space:
mode:
authorWilliam S Fulton <wsf@fultondesigns.co.uk>2010-06-21 06:18:54 +0000
committerWilliam S Fulton <wsf@fultondesigns.co.uk>2010-06-21 06:18:54 +0000
commit0bfeb75be2cd5a2080fbf365edfc9f22679b5f16 (patch)
tree08363e2844f241a928e5bb2d2e0c75ab0c2b7e6a /Tools
parent9ed2d0165c4bc858ee84f39be1bf0158262e9933 (diff)
downloadswig-0bfeb75be2cd5a2080fbf365edfc9f22679b5f16.tar.gz
update example version numbers and clarification of inputs
git-svn-id: https://swig.svn.sourceforge.net/svnroot/swig/trunk@12142 626c5289-ae23-0410-ae9c-e8d60b6d4f22
Diffstat (limited to 'Tools')
-rwxr-xr-xTools/mkwindows.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/Tools/mkwindows.sh b/Tools/mkwindows.sh
index fb2547e14..869fce01a 100755
--- a/Tools/mkwindows.sh
+++ b/Tools/mkwindows.sh
@@ -1,6 +1,7 @@
#!/bin/sh
# Build Windows distribution (swigwin-1.3.x.zip) -- requires running in either:
# - MinGW environment
# - Linux using MinGW cross compiler
# - Cygwin using MinGW compiler
@@ -21,8 +22,8 @@ if test x$1 != x; then
fi
else
echo "Usage: mkwindows.sh version [zip]"
- echo " Build Windows distribution. Works on Cygwin, MinGW or Linux"
- echo " version should be 1.3.x"
+ echo " Build SWIG Windows distribution from source tarball. Works on Cygwin, MinGW or Linux"
+ echo " version should be 2.0.x"
echo " zip is full path to zip program - default is /c/cygwin/bin/zip on MinGW, zip on Linux and Cygwin"
exit 1
fi
@@ -1,6 +1,7 @@
#!/bin/sh
-# Build Windows distribution (swigwin-1.3.x.zip) -- requires running in either:
+# Build Windows distribution (swigwin-2.0.x.zip) from source tarball (swig-2.0.x.tar.gz)
+# Requires running in either:
# - MinGW environment
# - Linux using MinGW cross compiler